@@ -3,16 +3,16 @@
 # Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -30,6 +30,7 @@ __license__   = "LGPL"
 
 import traceback
 import pyatspi
+import sys
 
 # Used to turn off all debugging.
 #
@@ -137,7 +138,10 @@ def printStack(level):
         println(level)
 
 def println(level, text = ""):
-    """Prints the text to stdout if debug is enabled.
+    """Prints the text to stderr unless debug is enabled.
+
+    If debug is enabled the text will be redirected to the
+    file debugFile.
 
     Arguments:
     - level: the accepted debug level
@@ -148,7 +152,7 @@ def println(level, text = ""):
         if debugFile:
             debugFile.writelines([text, "\n"])
         else:
-            print text
+            sys.stderr.writelines([text, "\n"])
 
 def printObjectEvent(level, event, sourceInfo=None):
     """Prints out an Python Event object.  The given level may be
@@ -237,9 +241,12 @@ def getAccessibleDetails(acc, indent="", includeApp=True):
     else:
         rel_string = ''
 
-    string += "name='%s' role='%s' state='%s' relations='%s'" \
-              % (acc.name or 'None', acc.getRoleName(),
-                 state_string, rel_string)
+    try:
+        string += "name='%s' role='%s' state='%s' relations='%s'" \
+                  % (acc.name or 'None', acc.getRoleName(),
+                     state_string, rel_string)
+    except DataError:
+        string += "(exception fetching data)"
 
     return string
 
